@@ -1,5 +1,6 @@
 from enum import Enum, unique
 
+
 @unique
 class Lang(Enum):
     EN = 'en'
@@ -9,4 +10,8 @@ class Lang(Enum):
     DE = 'de'
     RU = 'ru'
     IT = 'it'
-    NL = 'nl'
\ No newline at end of file
+    NL = 'nl'
+
+    @classmethod
+    def has_value(cls, value):
+        return value in cls._value2member_map_
